bayespy.inference.vmp.nodes.categorical_markov_chain.CategoricalMarkovChainMoments.__init__
===========================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.categorical_markov_chain

.. automethod:: CategoricalMarkovChainMoments.__init__